@@ -222,11 +222,12 @@ bool FTPStream::rename(const String &from, const String &to) {
 String &FTPStream::receiveBuffer(const String &filename) {
     int ret;
     char *dup_buf;
+    long dup_buf_size;
     (*this).tmpString = "";
     if ((*this).loggedIn == false) return (*this).tmpString;
-    ret = ftp_get_buffer_dup(&((*this).ftp_obj), filename.c_str(), &dup_buf);
+    ret = ftp_get_buffer_dup(&((*this).ftp_obj), filename.c_str(), &dup_buf, &dup_buf_size);
     if (dup_buf) {
-        (*this).tmpString = dup_buf;
+        (*this).tmpString.setBinary(dup_buf, dup_buf_size);
         free(dup_buf);
     }
     if (ret != FTP_NOERROR) {
@@ -315,12 +316,13 @@ Sheet &FTPStream::list() {
     int ret;
     char *list_data, *saveptr, *line;
     int line_len, row, i;
+    long dup_buf_size;
 
     (*this).tmpSheet.clear();
 
     if ((*this).loggedIn == false) return (*this).tmpSheet;
 
-    ret = ftp_list_dup(&((*this).ftp_obj), NULL, &list_data);
+    ret = ftp_list_dup(&((*this).ftp_obj), NULL, &list_data, &dup_buf_size);
 
     if (ret != FTP_NOERROR || !list_data ||
             (strncmp(list_data, "total ", 6)) || !strchr(list_data, '\n')) {
@@ -450,12 +452,13 @@ Sheet &FTPStream::nlist() {
     int ret;
     char *list_data, *saveptr, *line;
     int line_len, row, i;
+    long dup_buf_size;
 
     (*this).tmpSheet.clear();
 
     if ((*this).loggedIn == false) return (*this).tmpSheet;
 
-    ret = ftp_nlist_dup(&((*this).ftp_obj), NULL, &list_data);
+    ret = ftp_nlist_dup(&((*this).ftp_obj), NULL, &list_data, &dup_buf_size);
 
     if (ret != FTP_NOERROR || !list_data ||
             (strncmp(list_data, "total ", 6)) || !strchr(list_data, '\n')) {
