@@ -30,6 +30,7 @@ extern const char *STR_ISO8859_7;
 extern const char *STR_ISO8859_8;
 extern const char *STR_ISO8859_9;
 extern const char *STR_ISO8859_10;
+extern const char *STR_ISO8859_11;
 extern const char *STR_ISO8859_13;
 extern const char *STR_ISO8859_14;
 extern const char *STR_ISO8859_15;
@@ -38,6 +39,7 @@ extern const char *STR_KOI8_R;
 extern const char *STR_KOI8_U;
 extern const char *STR_CP1251;
 extern const char *STR_CP1252;
+extern const char *STR_CP1258;
 extern const char *STR_UTF8;
 extern const char *STR_UTF7;
 extern const char *STR_UTF7_IMAP;
